pro mnr_frm_fix,index,data

;+
; NAME
;	mnr_frm_fix
; PURPOSE
;	SXT images often have minor frames of data missing.
;	Usually these are zeroes.  Occasionally the missing
;	minor frames are set to 170 DN.  The purpose of this
;	program is to identify these minor frames in SXT
;	compressed images and set the 170 values to zero in
;	the missing minor frames.
; CALLING SEQUENCE
;	mnr_frm_fix,index,data
; INPUT
;	index, SXT index structure
;	data, raw, compressed, SXT image or data cube
;	   (mixed resoutions, image sizes, etc., are OK)
; OUTPUT
;	data cube with missinf minor frames set to zero
; RESTRICTIONS
;	Only works for sxt_compressed images.
; HISTORY
;	30-Jul-2004 LWA
;	17-Sep-2004 AkT: adopt for PFI '170' problem.
;	19-Sep-2004 AkT: adopt for de_compressed images.
;	26-Oct-2004 AkT: adopt for '170' lines with a few spikes. 
;	 3-Nov-2004 AkT: output comments simplified. 
;-
;print,'***** MNR_FRM_FIX.PRO is running *****'

;***** check file type (1: raw, 2: de_compressed) ***** 
typ=data_type(data)
case typ of
1 : val=170
2 : val=1353     ; fix(.10526*DN^2 - 12.473*DN + 431.14 + 0.5) for DN=170
else : val=170
endcase

for i=0,n_elements(index)-1 do begin

;***** decide the type of processing *****
   nx=gt_shape(index(i),/x)
   ny=gt_shape(index(i),/y)
   qpf=gt_pfi_ffi(index(i), /true_ffi)
   if (qpf eq 1) then typ = 1             ; for FFI
   if (qpf eq 0) then begin               ; for PFI
                        mm = nx mod 64 
                        if (nx eq 64) then typ = 1 $     ; for 64*64
                        else if (mm eq 0) then typ = 2 $ ; for nx=64*(integer) 
                             else typ = 1                ; for the others
                      end

;***** replace data value 170 --> 0 ***** 
   case typ of
;---------------------------------------------------------------------
   1 : begin    ; for all FFIs and PFIs with 1x1 ROI or irregular size  
;---------------------------------------------------------------------
   temp=intarr(ny)
   for yy=0,ny-1 do begin
       dummy=where(data(0:nx-1,yy,i) eq val,nyy)
       temp(yy)=nyy
   endfor
   jj=where(temp gt nx*0.9,njj)
;stop
   ; Make certain that entire row shows 170 DN.
   if njj gt 0 then begin
      data(0:nx-1,jj,i)=0
      print,'*** MNR_FRM_FIX: image No.',strtrim(i,1),',  ', $
                                strtrim(njj,1),' lines processed.'
    endif
    end
;---------------------------------------------------------------------
   2: begin     ;  for PFIs with a large regular ROI (2x2, 1x3, etc.)
;---------------------------------------------------------------------
   nn=fix(nx/64)   
   for k=0,nn-1 do begin
        xk=k*64
        temp=intarr(64)
        for yy=0,64-1 do begin
            dummy=where(data(xk:xk+64-1,yy,i) eq val,nyy)
            temp(yy)=nyy
        endfor
        jj=where(temp gt 64*0.9, njj)
;stop
        if njj gt 0 then begin
           data(xk:xk+64-1,jj,i)=0
print,'*** MNR_FRM_FIX: image No.',strtrim(i,1),' at the column No.', $
                  strtrim(k,1),', ',strtrim(njj,1),' lines processed.'
        endif
    endfor     
    end

    endcase
endfor

end
